from setuptools import setup, find_packages
setup(
    name='sema4ai',
    version='0.1',
    packages=find_packages(),
    description='A simple hello world package',
    long_description='This is a simple hello world package',
    author='Mikko Korpela',
    author_email='mikko@robocorp.com',
    url='https://github.com/robocorp/robocorp',
)
